class Book:
    """This class represents a book with attributes title, author, and year"""
    
    # __init__ is automatically called when we create new Book objects
    # we set the intial values of our attributes in __init__
    # (optional) default values can also be provided 
    def __init__(self, book_title="", book_author="", book_year=0):
        self._title = book_title
        self._author = book_author
        self._year = int(book_year)
    
    # accessor (getter) methods
    def get_title(self):
        return self._title

    def get_author(self):
        return self._author
    
    def get_year(self):
        return self._year
    
    # mutator (setter) methods
    def set_title(self, book_title):
        self._title = book_title
    
    def set_author(self, book_author):
        self._author = book_author
    
    def set_year(self, book_year):
        self._year = int(book_year)
    
    def num_words_in_title(self):
        """Returns the number of words in title of book"""
        return len(self._title.split())
    
    def same_author_as(self, other_book):
        """Check if self and otherBook have same author"""
        return self._author == other_book.get_author()
    
    def years_since_pub(self, currentYear):
        """Returns the number of years since book was published"""
        return currentYear - self._year
    
    # __str__ is used to generate a meaningful string representation for Book objects
    # __str__ is automatically called when we ask to print() a Book object
    def __str__(self):
        return "book.__str__"

    def __repr__(self):
        return "book.__repr__"
